#!/usr/bin/env python

#-----------------------------------------------------------------------
# database.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import queue
import psycopg2
import dotenv

#-----------------------------------------------------------------------

dotenv.load_dotenv()
_DATABASE_URL = os.environ['DATABASE_URL']

_connection_pool = queue.Queue()

#-----------------------------------------------------------------------

def _get_connection():
    try:
        conn = _connection_pool.get(block=False)
    except queue.Empty:
        conn = psycopg2.connect(_DATABASE_URL)
    return conn

def _put_connection(conn):
    _connection_pool.put(conn)

#-----------------------------------------------------------------------

def get_books(author):
    books = []
    connection = _get_connection()
    try:
        with connection.cursor() as cursor:
            query_str = "SELECT isbn, author, title FROM books "
            query_str += "WHERE author ILIKE %s"
            cursor.execute(query_str, [author+'%'])
            table = cursor.fetchall()
            for row in table:
                book = {'isbn': row[0], 'author': row[1],
                    'title': row[2]}
                books.append(book)
    finally:
        _put_connection(connection)

    return books

#-----------------------------------------------------------------------

# For testing:

def _test():
    books = get_books('ker')
    for book in books:
        print(book['isbn'])
        print(book['author'])
        print(book['title'])
        print()

if __name__ == '__main__':
    _test()
