#!/usr/bin/env python

#-----------------------------------------------------------------------
# database.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import psycopg2
import dotenv

#-----------------------------------------------------------------------

dotenv.load_dotenv()
_DATABASE_URL = os.environ['DATABASE_URL']

#-----------------------------------------------------------------------

def get_books(author):

    books = []

    with psycopg2.connect(_DATABASE_URL) as connection:

        with connection.cursor() as cursor:

            query_str = "SELECT isbn, author, title FROM books "
            query_str += "WHERE author ILIKE %s"
            cursor.execute(query_str, [author+'%'])

            table = cursor.fetchall()
            for row in table:
                book = {'isbn': row[0], 'author': row[1],
                    'title': row[2]}
                books.append(book)

    return books

#-----------------------------------------------------------------------

# For testing:

def _test():
    books = get_books('ker')
    for book in books:
        print(book['isbn'])
        print(book['author'])
        print(book['title'])
        print()

if __name__ == '__main__':
    _test()
